@@ -124,7 +124,7 @@ class Response(object):
 
         body = response.read()
 
-        if encoding in  ['zlib', 'deflate']:
+        if encoding in ['zlib', 'deflate']:
             body = decompress_data('zlib', body)
         elif encoding in ['gzip', 'x-gzip']:
             body = decompress_data('gzip', body)
@@ -138,6 +138,7 @@ class JsonResponse(Response):
     """
     A Base JSON Response class to derive from.
     """
+
     def parse_body(self):
         if len(self.body) == 0 and not self.parse_zero_length_body:
             return self.body
@@ -158,6 +159,7 @@ class XmlResponse(Response):
     """
     A Base XML Response class to derive from.
     """
+
     def parse_body(self):
         if len(self.body) == 0 and not self.parse_zero_length_body:
             return self.body
@@ -254,7 +256,7 @@ class LoggingConnection():
 
         encoding = headers.get('content-encoding', None)
 
-        if encoding in  ['zlib', 'deflate']:
+        if encoding in ['zlib', 'deflate']:
             body = decompress_data('zlib', body)
         elif encoding in ['gzip', 'x-gzip']:
             body = decompress_data('gzip', body)
@@ -653,8 +655,8 @@ class PollingConnection(Connection):
 
         - Returned 'job_id' is then used to construct a URL which is used for
           retrieving job status. Constructed URL is then periodically polled
-          until the response indicates that the job has completed or the timeout
-          of 'self.timeout' seconds has been reached.
+          until the response indicates that the job has completed or the
+          timeout of 'self.timeout' seconds has been reached.
 
         @type action: C{str}
         @param action: A path
@@ -753,7 +755,8 @@ class ConnectionKey(Connection):
         passed value.
         """
         super(ConnectionKey, self).__init__(secure=secure, host=host,
-                                            port=port, url=url, timeout=timeout)
+                                            port=port, url=url,
+                                            timeout=timeout)
         self.key = key
 
 
@@ -802,7 +805,9 @@ class BaseDriver(object):
                                  which support multiple API versions.
         @type       api_version: str
 
+        @requires: key, secret
         """
+
         self.key = key
         self.secret = secret
         self.secure = secure
@@ -821,7 +826,8 @@ class BaseDriver(object):
 
         self.api_version = api_version
 
-        self.connection = self.connectionCls(*args, **self._ex_connection_class_kwargs())
+        self.connection = self.connectionCls(*args,
+            **self._ex_connection_class_kwargs())
 
         self.connection.driver = self
         self.connection.connect()
