@@ -64,7 +64,7 @@ __all__ = [
     "ConnectionUserAndKey",
     "LibcloudHTTPSConnection",
     "LibcloudHTTPConnection"
-    ]
+]
 
 
 class UuidMixin(object):
@@ -98,7 +98,9 @@ class UuidMixin(object):
         same UUID!
         """
         if not self._uuid:
-            self._uuid = hashlib.sha1(b("%s:%d" % (self.id, self.driver.type))).hexdigest()
+            self._uuid = hashlib.sha1(b('%s:%d' %
+                                      (self.id, self.driver.type))).hexdigest()
+
         return self._uuid
 
     @property
@@ -165,8 +167,8 @@ class Node(UuidMixin):
         self.extra = extra or {}
         UuidMixin.__init__(self)
 
-    # Note: getters and setters bellow are here only for backward compatibility.
-    # They will be removed in the next release.
+    # Note: getters and setters bellow are here only for backward
+    # compatibility. They will be removed in the next release.
 
     def _set_public_ips(self, value):
         self.public_ips = value
@@ -363,6 +365,57 @@ class NodeAuthPassword(object):
         return '<NodeAuthPassword>'
 
 
+class StorageVolume(UuidMixin):
+    """
+    A base StorageVolume class to derive from.
+    """
+
+    def __init__(self, id, name, size, driver, extra=None):
+        self.id = id
+        self.name = name
+        self.size = size
+        self.driver = driver
+        self.extra = extra
+        UuidMixin.__init__(self)
+
+    def attach(self, node, device=None):
+        """
+        Attach this volume to a node.
+
+        @param      node: Node to attach volume to
+        @type       node: L{Node}
+
+        @param      device: Where the device is exposed,
+                            e.g. '/dev/sdb (optional)
+        @type       device: C{str}
+
+        @returns C{bool}
+        """
+
+        return self.driver.attach_volume(node=node, volume=self, device=device)
+
+    def detach(self):
+        """
+        Detach this volume from its node
+
+        @returns C{bool}
+        """
+
+        return self.driver.detach_volume(volume=self)
+
+    def destroy(self):
+        """Destroy this storage volume.
+
+        @returns C{bool}
+        """
+
+        return self.driver.destroy_volume(volume=self)
+
+    def __repr__(self):
+        return '<StorageVolume id=%s size=%s driver=%s>' % (
+               self.id, self.size, self.driver.name)
+
+
 class NodeDriver(BaseDriver):
     """
     A base NodeDriver class to derive from
@@ -393,6 +446,9 @@ class NodeDriver(BaseDriver):
 
     def __init__(self, key, secret=None, secure=True, host=None, port=None,
                  api_version=None, **kwargs):
+        """
+        @requires: key, secret
+        """
         super(NodeDriver, self).__init__(key=key, secret=secret, secure=secure,
                                          host=host, port=port,
                                          api_version=api_version, **kwargs)
@@ -401,7 +457,7 @@ class NodeDriver(BaseDriver):
         """Create a new node instance.
 
         @keyword    name:   String with a name for this new node (required)
-        @type       name:   str
+        @type       name:   C{str}
 
         @keyword    size:   The size of resources allocated to this node.
                             (required)
@@ -418,7 +474,8 @@ class NodeDriver(BaseDriver):
                             (optional)
         @type       auth:   L{NodeAuthSSHKey} or L{NodeAuthPassword}
 
-        @return: The newly created L{Node}.
+        @return: The newly created node.
+        @rtype: L{Node}
         """
         raise NotImplementedError(
             'create_node not implemented for this driver')
@@ -432,7 +489,8 @@ class NodeDriver(BaseDriver):
         @param node: The node to be destroyed
         @type node: L{Node}
 
-        @return: C{bool} True if the destroy was successful, otherwise False
+        @return: True if the destroy was successful, otherwise False
+        @rtype: C{bool}
         """
         raise NotImplementedError(
             'destroy_node not implemented for this driver')
@@ -444,7 +502,8 @@ class NodeDriver(BaseDriver):
         @param node: The node to be rebooted
         @type node: L{Node}
 
-        @return: C{bool} True if the reboot was successful, otherwise False
+        @return: True if the reboot was successful, otherwise False
+        @rtype: C{bool}
         """
         raise NotImplementedError(
             'reboot_node not implemented for this driver')
@@ -452,7 +511,8 @@ class NodeDriver(BaseDriver):
     def list_nodes(self):
         """
         List all nodes
-        @return: C{list} of L{Node} objects
+        @return:  list of node objects
+        @rtype: C{list} of L{Node}
         """
         raise NotImplementedError(
             'list_nodes not implemented for this driver')
@@ -464,7 +524,8 @@ class NodeDriver(BaseDriver):
         @keyword location: The location at which to list images
         @type location: L{NodeLocation}
 
-        @return: C{list} of L{NodeImage} objects
+        @return: list of node image objects
+        @rtype: C{list} of L{NodeImage}
         """
         raise NotImplementedError(
             'list_images not implemented for this driver')
@@ -476,7 +537,8 @@ class NodeDriver(BaseDriver):
         @keyword location: The location at which to list sizes
         @type location: L{NodeLocation}
 
-        @return: C{list} of L{NodeSize} objects
+        @return: list of node size objects
+        @rtype: C{list} of L{NodeSize}
         """
         raise NotImplementedError(
             'list_sizes not implemented for this driver')
@@ -484,7 +546,9 @@ class NodeDriver(BaseDriver):
     def list_locations(self):
         """
         List data centers for a provider
-        @return: C{list} of L{NodeLocation} objects
+
+        @return: list of node location objects
+        @rtype: C{list} of L{NodeLocation}
         """
         raise NotImplementedError(
             'list_locations not implemented for this driver')
@@ -501,6 +565,27 @@ class NodeDriver(BaseDriver):
         timing out).  This exception includes a Node object which you may want
         to destroy if incomplete deployments are not desirable.
 
+        >>> from libcloud.compute.drivers.dummy import DummyNodeDriver
+        >>> from libcloud.compute.deployment import ScriptDeployment
+        >>> from libcloud.compute.deployment import MultiStepDeployment
+        >>> from libcloud.compute.base import NodeAuthSSHKey
+        >>> driver = DummyNodeDriver(0)
+        >>> key = NodeAuthSSHKey('...') # read from file
+        >>> script = ScriptDeployment("yum -y install emacs strace tcpdump")
+        >>> msd = MultiStepDeployment([key, script])
+        >>> def d():
+        ...     try:
+        ...         node = driver.deploy_node(deploy=msd)
+        ...     except NotImplementedError:
+        ...         print ("not implemented for dummy driver")
+        >>> d()
+        not implemented for dummy driver
+
+        Deploy node is typically not overridden in subclasses.  The
+        existing implementation should be able to handle most such.
+
+        @inherits: L{NodeDriver.create_node}
+
         @keyword    deploy: Deployment to run once machine is online and
                             availble to SSH.
         @type       deploy: L{Deployment}
@@ -523,7 +608,7 @@ class NodeDriver(BaseDriver):
 
         @keyword    ssh_key: A path (or paths) to an SSH private key with which
                              to attempt to authenticate. (optional)
-        @type       ssh_key: C{string} or C{list} of C{string}s
+        @type       ssh_key: C{str} or C{list} of C{str}
 
         @keyword    max_tries: How many times to retry if a deployment fails
                                before giving up (default is 3)
@@ -532,27 +617,6 @@ class NodeDriver(BaseDriver):
         @keyword    ssh_interface: The interface to wait for. Default is
                                    'public_ips', other option is 'private_ips'.
         @type       ssh_interface: C{str}
-
-        See L{NodeDriver.create_node} for more keyword args.
-
-        >>> from libcloud.compute.drivers.dummy import DummyNodeDriver
-        >>> from libcloud.compute.deployment import ScriptDeployment
-        >>> from libcloud.compute.deployment import MultiStepDeployment
-        >>> from libcloud.compute.base import NodeAuthSSHKey
-        >>> driver = DummyNodeDriver(0)
-        >>> key = NodeAuthSSHKey('...') # read from file
-        >>> script = ScriptDeployment("yum -y install emacs strace tcpdump")
-        >>> msd = MultiStepDeployment([key, script])
-        >>> def d():
-        ...     try:
-        ...         node = driver.deploy_node(deploy=msd)
-        ...     except NotImplementedError:
-        ...         print ("not implemented for dummy driver")
-        >>> d()
-        not implemented for dummy driver
-
-        Deploy node is typically not overridden in subclasses.  The
-        existing implementation should be able to handle most such.
         """
         if not libcloud.compute.ssh.have_paramiko:
             raise RuntimeError('paramiko is not installed. You can install ' +
@@ -562,7 +626,7 @@ class NodeDriver(BaseDriver):
 
         if 'create_node' not in self.features:
             raise NotImplementedError(
-                    'deploy_node not implemented for this driver')
+                'deploy_node not implemented for this driver')
         elif 'generates_password' not in self.features["create_node"]:
             if 'password' not in self.features["create_node"] and \
                'ssh_key' not in self.features["create_node"]:
@@ -570,7 +634,8 @@ class NodeDriver(BaseDriver):
                     'deploy_node not implemented for this driver')
 
             if 'auth' not in kwargs:
-                kwargs['auth'] = NodeAuthPassword(binascii.hexlify(os.urandom(16)))
+                value = os.urandom(16)
+                kwargs['auth'] = NodeAuthPassword(binascii.hexlify(value))
 
             if 'ssh_key' not in kwargs:
                 password = kwargs['auth'].password
@@ -584,9 +649,10 @@ class NodeDriver(BaseDriver):
         try:
             # Wait until node is up and running and has IP assigned
             ssh_interface = kwargs.get('ssh_interface', 'public_ips')
-            node, ip_addresses = self._wait_until_running(node=node,
-                    wait_period=3, timeout=NODE_ONLINE_WAIT_TIMEOUT,
-                    ssh_interface=ssh_interface)
+            node, ip_addresses = self._wait_until_running(
+                node=node,
+                wait_period=3, timeout=NODE_ONLINE_WAIT_TIMEOUT,
+                ssh_interface=ssh_interface)
 
             if password:
                 node.extra['password'] = password
@@ -617,8 +683,76 @@ class NodeDriver(BaseDriver):
 
         return node
 
+    def create_volume(self, size, name, location=None, snapshot=None):
+        """
+        Create a new volume.
+
+        @param      size: Size of volume in gigabytes (required)
+        @type       size: C{int}
+
+        @keyword    name: Name of the volume to be created
+        @type       name: C{str}
+
+        @keyword    location: Which data center to create a volume in. If
+                               empty, undefined behavoir will be selected.
+                               (optional)
+        @type       location: L{NodeLocation}
+
+        @keyword    snapshot:  Name of snapshot from which to create the new
+                               volume.  (optional)
+        @type       snapshot:  C{str}
+
+        @return: The newly created volume.
+        @rtype: L{StorageVolume}
+        """
+        raise NotImplementedError(
+            'create_volume not implemented for this driver')
+
+    def destroy_volume(self, volume):
+        """
+        Destroys a storage volume.
+
+        @param      volume: Volume to be destroyed
+        @type       volume: L{StorageVolume}
+
+        @rtype: C{bool}
+        """
+
+        raise NotImplementedError(
+            'destroy_volume not implemented for this driver')
+
+    def attach_volume(self, node, volume, device=None):
+        """
+        Attaches volume to node.
+
+        @param      node: Node to attach volume to
+        @type       node: L{Node}
+
+        @param      volume: Volume to attach
+        @type       volume: L{StorageVolume}
+
+        @param      device: Where the device is exposed,
+                            e.g. '/dev/sdb (optional)
+        @type       device: C{str}
+
+        @rtype: C{bool}
+        """
+        raise NotImplementedError('attach not implemented for this driver')
+
+    def detach_volume(self, volume):
+        """
+        Detaches a volume from a node.
+
+        @param      volume: Volume to be detached
+        @type       volume: L{StorageVolume}
+
+        @rtype: C{bool}
+        """
+
+        raise NotImplementedError('detach not implemented for this driver')
+
     def _wait_until_running(self, node, wait_period=3, timeout=600,
-                            ssh_interface='public_ips'):
+                            ssh_interface='public_ips', force_ipv4=True):
         """
         Block until node is fully booted and has an IP address assigned.
 
@@ -638,9 +772,23 @@ class NodeDriver(BaseDriver):
                                    'private_ips'.
         @type       ssh_interface: C{str}
 
+        @keyword    force_ipv4: Ignore ipv6 IP addresses (default is True).
+        @type       force_ipv4: C{bool}
+
         @return: C{(Node, ip_addresses)} tuple of Node instance and
                  list of ip_address on success.
         """
+        def is_supported(address):
+            """Return True for supported address"""
+            if force_ipv4 and not is_valid_ip_address(address=address,
+                                                      family=socket.AF_INET):
+                return False
+            return True
+
+        def filter_addresses(addresses):
+            """Return list of supported addresses"""
+            return [a for a in addresses if is_supported(a)]
+
         start = time.time()
         end = start + timeout
 
@@ -657,9 +805,10 @@ class NodeDriver(BaseDriver):
                                     + 'but multiple nodes have same UUID'),
                                     driver=self)
 
-            if (len(nodes) == 1 and nodes[0].state == NodeState.RUNNING and \
-                getattr(nodes[0], ssh_interface)):
-                return (nodes[0], getattr(nodes[0], ssh_interface))
+            if (len(nodes) == 1 and nodes[0].state == NodeState.RUNNING and
+                    filter_addresses(getattr(nodes[0], ssh_interface))):
+                return (nodes[0], filter_addresses(getattr(nodes[0],
+                                                   ssh_interface)))
             else:
                 time.sleep(wait_period)
                 continue
@@ -667,7 +816,7 @@ class NodeDriver(BaseDriver):
         raise LibcloudError(value='Timed out after %s seconds' % (timeout),
                             driver=self)
 
-    def _ssh_client_connect(self, ssh_client, timeout=300):
+    def _ssh_client_connect(self, ssh_client, wait_period=1.5, timeout=300):
         """
         Try to connect to the remote SSH server. If a connection times out or
         is refused it is retried up to timeout number of seconds.
@@ -675,6 +824,10 @@ class NodeDriver(BaseDriver):
         @keyword    ssh_client: A configured SSHClient instance
         @type       ssh_client: C{SSHClient}
 
+        @keyword    wait_period: How many seconds to wait between each loop
+                                 iteration (default is 1.5)
+        @type       wait_period: C{int}
+
         @keyword    timeout: How many seconds to wait before timing out
                              (default is 600)
         @type       timeout: C{int}
@@ -691,6 +844,7 @@ class NodeDriver(BaseDriver):
                 # Retry if a connection is refused or timeout
                 # occurred
                 ssh_client.close()
+                time.sleep(wait_period)
                 continue
             else:
                 return ssh_client
@@ -763,6 +917,19 @@ def is_private_subnet(ip):
     return False
 
 
+def is_valid_ip_address(address, family=socket.AF_INET):
+    """
+    Check if the provided address is valid IPv4 or IPv6 adddress.
+
+    @return: C{bool} True if the provided address is valid.
+    """
+    try:
+        socket.inet_pton(family, address)
+    except socket.error:
+        return False
+    return True
+
+
 if __name__ == "__main__":
     import doctest
     doctest.testmod()
