@@ -128,8 +128,12 @@ class RackspaceUKDNSConnection(RackspaceDNSConnection):
 
 
 class RackspaceDNSDriver(DNSDriver, OpenStackDriverMixin):
+    website = 'http://www.rackspace.com/'
 
     def __init__(self, *args, **kwargs):
+        """
+        @requires: key, secret
+        """
         OpenStackDriverMixin.__init__(self, *args, **kwargs)
         super(RackspaceDNSDriver, self).__init__(*args, **kwargs)
 
@@ -359,7 +363,11 @@ class RackspaceDNSDriver(DNSDriver, OpenStackDriverMixin):
         @param name: Record name.
         @type name: C{str}
         """
-        name = '%s.%s' % (name, domain)
+        if name:
+            name = '%s.%s' % (name, domain)
+        else:
+            name = domain
+
         return name
 
     def _to_partial_record_name(self, domain, name):
